@@ -79,9 +79,9 @@ class ToolCmake(Tool):
         Tool.__init__(
             self,
             "cmake",
-            version="3.25.3",
+            version="3.26.2",
             archive_url="https://github.com/Kitware/CMake/releases/download/v{version}/cmake-{version}-windows-x86_64.zip",
-            hash="d129425d569140b729210f3383c246dec19c4183f7d0afae1837044942da3b4b",
+            hash="193d93b049b335b003a162d6a24633d4ba2d8d7ee9b392d54dfde88924d792f8",
             dir_part="cmake-{version}-windows-x86_64",
         )
 
@@ -188,31 +188,6 @@ class ToolNinja(Tool):
         )
 
 
-@tool_add
-class ToolNuget(Tool):
-    def __init__(self):
-        Tool.__init__(
-            self,
-            "nuget",
-            version="6.4.0",
-            archive_url="https://dist.nuget.org/win-x86-commandline/v{version}/nuget.exe",
-            archive_file_name="nuget-{version}.exe",
-            hash="26730829b240581a3e6a4e276b9ace088930032df0c680d5591beccf6452374e",
-            dir_part="nuget-{version}",
-            exe_name="nuget.exe",
-        )
-
-    def unpack(self):
-        # Download the exe file and copy it on the tool directory
-        self.mark_deps = extract_exec(
-            self.archive_file,
-            self.build_dir,
-            check_file=self.full_exe,
-            force_dest=self.full_exe,
-            check_mark=True,
-        )
-
-
 @tool_add
 class ToolPerl(Tool):
     def __init__(self):
