@@ -122,7 +122,7 @@ class Log:
                 os.rename(self.log_file, old_file)
 
         self.operations = []
-        self.fo = open(self.log_file, "at", encoding="utf-8")
+        self.fo = open(self.log_file, "a", encoding="utf-8")
         self._output("Script started")
         if created:
             self.log(f"Log directory {file_path} created")
